"""Regional Google cookie domains (same allowlist idea as notebooklm-py)."""

# Suffix after ".google." for domains like .google.com.sg, .google.co.uk, .google.de
GOOGLE_REGIONAL_CCTLDS = frozenset(
    {
        "com.sg",
        "com.au",
        "com.br",
        "com.mx",
        "com.ar",
        "com.hk",
        "com.tw",
        "com.my",
        "com.ph",
        "com.vn",
        "com.pk",
        "com.bd",
        "com.ng",
        "com.eg",
        "com.tr",
        "com.ua",
        "com.co",
        "com.pe",
        "com.sa",
        "com.ae",
        "co.uk",
        "co.jp",
        "co.in",
        "co.kr",
        "co.za",
        "co.nz",
        "co.id",
        "co.th",
        "co.il",
        "co.ve",
        "co.cr",
        "co.ke",
        "co.ug",
        "co.tz",
        "co.ma",
        "co.ao",
        "co.mz",
        "co.zw",
        "co.bw",
        "cn",
        "de",
        "fr",
        "it",
        "es",
        "nl",
        "pl",
        "ru",
        "ca",
        "be",
        "at",
        "ch",
        "se",
        "no",
        "dk",
        "fi",
        "pt",
        "gr",
        "cz",
        "ro",
        "hu",
        "ie",
        "sk",
        "bg",
        "hr",
        "si",
        "lt",
        "lv",
        "ee",
        "lu",
        "cl",
        "cat",
    }
)
